@@ -472,7 +472,7 @@ def parse_references(pubmed_article, reference_list):
         return references
     else:
         references = ";".join(
-            [ref["pmid"] for ref in references if ref["pmid"] is not ""]
+            [ref["pmid"] for ref in references if ref["pmid"] != ""]
         )
         return references
 
@@ -560,7 +560,7 @@ def parse_article_info(
             [
                 author.get("affiliation", "")
                 for author in authors_dict
-                if author.get("affiliation", "") is not ""
+                if author.get("affiliation", "") != ""
             ]
         )
         authors = ";".join(
